SFLOW_GMETRIC(SFLOW_M_load_one,"load_one","", GANGLIA_SLOPE_BOTH,"%.2f","load",NULL,"One minute load average")
SFLOW_GMETRIC(SFLOW_M_load_five,"load_five","", GANGLIA_SLOPE_BOTH,"%.2f","load",NULL,"Five minute load average")
SFLOW_GMETRIC(SFLOW_M_load_fifteen,"load_fifteen","", GANGLIA_SLOPE_BOTH,"%.2f","load",NULL,"Fifteen minute load average")
SFLOW_GMETRIC(SFLOW_M_os_release, "os_release", "", GANGLIA_SLOPE_ZERO, "%s", "system", NULL, "Operating System Release" )
SFLOW_GMETRIC(SFLOW_M_machine_type, "machine_type", "", GANGLIA_SLOPE_ZERO, "%s", "system", NULL, "Machine Type" )
SFLOW_GMETRIC(SFLOW_M_os_name, "os_name", "", GANGLIA_SLOPE_ZERO, "%s", "system", NULL, "Operating System" )
SFLOW_GMETRIC(SFLOW_M_uuid, "uuid", "", GANGLIA_SLOPE_ZERO, "%s", "system", NULL, "System UUID" )
SFLOW_GMETRIC(SFLOW_M_heartbeat, "heartbeat", "", GANGLIA_SLOPE_ZERO, "%u", "system", NULL, "Heartbeat" )
SFLOW_GMETRIC(SFLOW_M_proc_run, "proc_run", "", GANGLIA_SLOPE_BOTH, "%u", "process", NULL, "Total Running Processes" )
SFLOW_GMETRIC(SFLOW_M_proc_total, "proc_total", "", GANGLIA_SLOPE_BOTH, "%u", "process", NULL, "Total Processes" )
SFLOW_GMETRIC(SFLOW_M_cpu_num, "cpu_num", "CPUs", GANGLIA_SLOPE_ZERO, "%u", "cpu", NULL, "CPU Count" )
SFLOW_GMETRIC(SFLOW_M_cpu_speed, "cpu_speed", "MHz", GANGLIA_SLOPE_ZERO, "%u", "cpu", NULL, "CPU Speed" )
SFLOW_GMETRIC(SFLOW_M_cpu_boottime, "boottime", "s", GANGLIA_SLOPE_ZERO, "%u", "cpu", NULL, "Last Boot Time" )
SFLOW_GMETRIC(SFLOW_M_cpu_user, "cpu_user", "%", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU User" )
SFLOW_GMETRIC(SFLOW_M_cpu_nice, "cpu_nice", "%", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU Nice" )
SFLOW_GMETRIC(SFLOW_M_cpu_system, "cpu_system", "%", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU System" )
SFLOW_GMETRIC(SFLOW_M_cpu_idle, "cpu_idle", "%", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU Idle" )
SFLOW_GMETRIC(SFLOW_M_cpu_wio, "cpu_wio", "%", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU I/O Wait" )
SFLOW_GMETRIC(SFLOW_M_cpu_intr, "cpu_intr", "", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU Interrupts" )
SFLOW_GMETRIC(SFLOW_M_cpu_sintr, "cpu_sintr", "", GANGLIA_SLOPE_BOTH, "%.2f", "cpu", NULL, "CPU Soft Interrupts" )
SFLOW_GMETRIC(SFLOW_M_interrupts, "interrupts", "", GANGLIA_SLOPE_BOTH, "%.0f", "cpu", NULL, "Interrupts" )
SFLOW_GMETRIC(SFLOW_M_contexts, "contexts", "", GANGLIA_SLOPE_BOTH, "%.0f", "cpu", NULL, "Context Switches" )
SFLOW_GMETRIC(SFLOW_M_mem_total, "mem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "memory", NULL, "Memory Total" )
SFLOW_GMETRIC(SFLOW_M_mem_free, "mem_free", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Free Memory" )
SFLOW_GMETRIC(SFLOW_M_mem_shared, "mem_shared", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Shared Memory" )
SFLOW_GMETRIC(SFLOW_M_mem_buffers, "mem_buffers", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Memory Buffers" )
SFLOW_GMETRIC(SFLOW_M_mem_cached, "mem_cached", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Cached Memory" )
SFLOW_GMETRIC(SFLOW_M_swap_total, "swap_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "memory", NULL, "Swap Space Total" )
SFLOW_GMETRIC(SFLOW_M_swap_free, "swap_free", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Free Swap Space" )
SFLOW_GMETRIC(SFLOW_M_page_in, "page_in", "", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Pages In" )
SFLOW_GMETRIC(SFLOW_M_page_out, "page_out", "", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Pages Out" )
SFLOW_GMETRIC(SFLOW_M_swap_in, "swap_in", "", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Swap Pages In" )
SFLOW_GMETRIC(SFLOW_M_swap_out, "swap_out", "", GANGLIA_SLOPE_BOTH, "%.0f", "memory", NULL, "Swap Pages Out" )
SFLOW_GMETRIC(SFLOW_M_disk_total, "disk_total", "GB", GANGLIA_SLOPE_BOTH, "%.3f", "disk", NULL, "Total Disk Space" )
SFLOW_GMETRIC(SFLOW_M_disk_free, "disk_free", "GB", GANGLIA_SLOPE_BOTH, "%.3f", "disk", NULL, "Free Disk Space" )
SFLOW_GMETRIC(SFLOW_M_part_max_used, "part_max_used", "%", GANGLIA_SLOPE_BOTH, "%.2f", "disk", NULL, "Maximum Disk Space Used" )
SFLOW_GMETRIC(SFLOW_M_reads, "reads", "", GANGLIA_SLOPE_BOTH, "%.0f", "disk", NULL, "Reads" )
SFLOW_GMETRIC(SFLOW_M_bytes_read, "bytes_read", "", GANGLIA_SLOPE_BOTH, "%.0f", "disk", NULL, "Bytes Read" )
SFLOW_GMETRIC(SFLOW_M_read_time, "read_time", "mS", GANGLIA_SLOPE_BOTH, "%.2f", "disk", NULL, "Read Time" )
SFLOW_GMETRIC(SFLOW_M_writes, "writes", "", GANGLIA_SLOPE_BOTH, "%.0f", "disk", NULL, "Writes" )
SFLOW_GMETRIC(SFLOW_M_bytes_written, "bytes_written", "", GANGLIA_SLOPE_BOTH, "%.0f", "disk", NULL, "Bytes Written" )
SFLOW_GMETRIC(SFLOW_M_write_time, "write_time", "mS", GANGLIA_SLOPE_BOTH, "%.2f", "disk", NULL, "Write Time" )
SFLOW_GMETRIC(SFLOW_M_bytes_in, "bytes_in", "bytes/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Bytes Received" )
SFLOW_GMETRIC(SFLOW_M_pkts_in, "pkts_in", "packets/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Packets Received" )
SFLOW_GMETRIC(SFLOW_M_errs_in, "errs_in", "errors/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Input Errors" )
SFLOW_GMETRIC(SFLOW_M_drops_in, "drops_in", "drops/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Input Drops" )
SFLOW_GMETRIC(SFLOW_M_bytes_out, "bytes_out", "bytes/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Bytes Sent" )
SFLOW_GMETRIC(SFLOW_M_pkts_out, "pkts_out", "packets/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Packets Sent" )
SFLOW_GMETRIC(SFLOW_M_errs_out, "errs_out", "errors/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Output Errors" )
SFLOW_GMETRIC(SFLOW_M_drops_out, "drops_out", "drops/sec", GANGLIA_SLOPE_BOTH, "%.2f", "network", NULL, "Output Drops" )
SFLOW_GMETRIC(SFLOW_M_vnode_mem_total, "vnode_mem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "hypervisor", NULL, "Hypervisor Memory Total" )
SFLOW_GMETRIC(SFLOW_M_vnode_mem_free, "vnode_mem_free", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "hypervisor", NULL, "Hypervisor Free Memory" )
SFLOW_GMETRIC(SFLOW_M_vnode_cpu_speed, "vnode_cpu_speed", "MHz", GANGLIA_SLOPE_ZERO, "%u", "hypervisor", NULL, "Hypervisor CPU Speed" )
SFLOW_GMETRIC(SFLOW_M_vnode_cpu_num, "vnode_cpu_num", "", GANGLIA_SLOPE_ZERO, "%u", "hypervisor", NULL, "Hypervisor CPU Count" )
SFLOW_GMETRIC(SFLOW_M_vnode_domains, "vnode_domains", "", GANGLIA_SLOPE_BOTH, "%u", "hypervisor", NULL, "Hypervisor Domain Count" )
SFLOW_GMETRIC(SFLOW_M_vcpu_state, "vcpu_state", "", GANGLIA_SLOPE_ZERO, "%s", "vm cpu", NULL, "VM CPU State" )
SFLOW_GMETRIC(SFLOW_M_vcpu_util, "vcpu_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "vm cpu", NULL, "VM CPU Utilization" )
SFLOW_GMETRIC(SFLOW_M_vcpu_num, "vcpu_num", "", GANGLIA_SLOPE_ZERO, "%u", "vm cpu", NULL, "VM CPU Count" )
SFLOW_GMETRIC(SFLOW_M_vmem_total, "vmem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "vm memory", NULL, "VM Memory Total" )
SFLOW_GMETRIC(SFLOW_M_vmem_util, "vmem_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "vm memory", NULL, "VM Memory Utilization" )
SFLOW_GMETRIC(SFLOW_M_vdisk_capacity, "vdisk_capacity", "GB", GANGLIA_SLOPE_ZERO, "%.3f", "vm disk", NULL, "VDisk Capacity" )
SFLOW_GMETRIC(SFLOW_M_vdisk_total, "vdisk_total", "GB", GANGLIA_SLOPE_BOTH, "%.3f", "vm disk", NULL, "Total VDisk Space" )
SFLOW_GMETRIC(SFLOW_M_vdisk_free, "vdisk_free", "GB", GANGLIA_SLOPE_BOTH, "%.3f", "vm disk", NULL, "Free VDisk Space" )
SFLOW_GMETRIC(SFLOW_M_vdisk_reads, "vdisk_reads", "", GANGLIA_SLOPE_BOTH, "%.0f", "vm disk", NULL, "VM Reads" )
SFLOW_GMETRIC(SFLOW_M_vdisk_bytes_read, "vdisk_bytes_read", "", GANGLIA_SLOPE_BOTH, "%.0f", "vm disk", NULL, "VM Bytes Read" )
SFLOW_GMETRIC(SFLOW_M_vdisk_writes, "vdisk_writes", "", GANGLIA_SLOPE_BOTH, "%.0f", "vm disk", NULL, "VM Writes" )
SFLOW_GMETRIC(SFLOW_M_vdisk_bytes_written, "vdisk_bytes_written", "", GANGLIA_SLOPE_BOTH, "%.0f", "vm disk", NULL, "VM Bytes Written" )
SFLOW_GMETRIC(SFLOW_M_vdisk_errs, "vdisk_errs", "errors/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm disk", NULL, "VM Disk Errors" )
SFLOW_GMETRIC(SFLOW_M_vbytes_in, "vbytes_in", "bytes/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Bytes Received" )
SFLOW_GMETRIC(SFLOW_M_vpkts_in, "vpkts_in", "packets/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Packets Received" )
SFLOW_GMETRIC(SFLOW_M_verrs_in, "verrs_in", "errors/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Input Errors" )
SFLOW_GMETRIC(SFLOW_M_vdrops_in, "vdrops_in", "drops/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Input Drops" )
SFLOW_GMETRIC(SFLOW_M_vbytes_out, "vbytes_out", "bytes/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Bytes Sent" )
SFLOW_GMETRIC(SFLOW_M_vpkts_out, "vpkts_out", "packets/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Packets Sent" )
SFLOW_GMETRIC(SFLOW_M_verrs_out, "verrs_out", "errors/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Output Errors" )
SFLOW_GMETRIC(SFLOW_M_vdrops_out, "vdrops_out", "drops/sec", GANGLIA_SLOPE_BOTH, "%.2f", "vm network", NULL, "VM Output Drops" )
SFLOW_GMETRIC(SFLOW_M_mc_boottime, "mc_boottime", "s", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Start Time" )
SFLOW_GMETRIC(SFLOW_M_mc_rusage_user, "mc_rusage_user", "mS", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache rusage_user" )
SFLOW_GMETRIC(SFLOW_M_mc_rusage_system, "mc_rusage_system", "mS", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache rusage_system" )
SFLOW_GMETRIC(SFLOW_M_mc_curr_conns, "mc_curr_conns", "", GANGLIA_SLOPE_BOTH, "%u", "memcache", NULL, "Memcache Current Connections" )
SFLOW_GMETRIC(SFLOW_M_mc_total_conns, "mc_total_conns", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Total Connections" )
SFLOW_GMETRIC(SFLOW_M_mc_conn_structs, "mc_conn_structs", "", GANGLIA_SLOPE_BOTH, "%u", "memcache", NULL, "Memcache Connection Structs" )
SFLOW_GMETRIC(SFLOW_M_mc_cmd_get, "mc_cmd_get", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Command GET" )
SFLOW_GMETRIC(SFLOW_M_mc_cmd_set, "mc_cmd_set", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Command SET" )
SFLOW_GMETRIC(SFLOW_M_mc_cmd_flush, "mc_cmd_flush", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Command FLUSH" )
SFLOW_GMETRIC(SFLOW_M_mc_get_hits, "mc_get_hits", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache GET Hits" )
SFLOW_GMETRIC(SFLOW_M_mc_get_misses, "mc_get_misses", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache GET Misses" )
SFLOW_GMETRIC(SFLOW_M_mc_delete_misses, "mc_delete_misses", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache DELETE Misses" )
SFLOW_GMETRIC(SFLOW_M_mc_delete_hits, "mc_delete_hits", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache DELETE Hits" )
SFLOW_GMETRIC(SFLOW_M_mc_incr_misses, "mc_incr_misses", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache INCR Misses" )
SFLOW_GMETRIC(SFLOW_M_mc_incr_hits, "mc_incr_hits", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache INCR Hits" )
SFLOW_GMETRIC(SFLOW_M_mc_decr_misses, "mc_decr_misses", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache DECR Misses" )
SFLOW_GMETRIC(SFLOW_M_mc_decr_hits, "mc_decr_hits", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache DECR Hits" )
SFLOW_GMETRIC(SFLOW_M_mc_cas_misses, "mc_cas_misses", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache CAS Misses" )
SFLOW_GMETRIC(SFLOW_M_mc_cas_hits, "mc_cas_hits", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache CAS Hits" )
SFLOW_GMETRIC(SFLOW_M_mc_cas_badval, "mc_cas_badval", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache CAS Badval" )
SFLOW_GMETRIC(SFLOW_M_mc_auth_cmds, "mc_auth_cmds", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache AUTH Cmds" )
SFLOW_GMETRIC(SFLOW_M_mc_auth_errors, "mc_auth_errors", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache AUTH Errors" )
SFLOW_GMETRIC(SFLOW_M_mc_bytes_read, "mc_bytes_read", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Bytes Read" )
SFLOW_GMETRIC(SFLOW_M_mc_bytes_written, "mc_bytes_written", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Bytes Written" )
SFLOW_GMETRIC(SFLOW_M_mc_limit_maxbytes, "mc_limit_maxbytes", "", GANGLIA_SLOPE_ZERO, "%.0f", "memcache", NULL, "Memcache Limit MaxBytes" )
SFLOW_GMETRIC(SFLOW_M_mc_accepting_conns, "mc_accepting_conns", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Accepting Connections" )
SFLOW_GMETRIC(SFLOW_M_mc_listen_disabled_num, "mc_listen_disabled_num", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Listen Disabled" )
SFLOW_GMETRIC(SFLOW_M_mc_threads, "mc_threads", "", GANGLIA_SLOPE_ZERO, "%u", "memcache", NULL, "Memcache Threads" )
SFLOW_GMETRIC(SFLOW_M_mc_conn_yields, "mc_conn_yields", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Connection Yields" )
SFLOW_GMETRIC(SFLOW_M_mc_bytes, "mc_bytes", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Bytes" )
SFLOW_GMETRIC(SFLOW_M_mc_curr_items, "mc_curr_items", "", GANGLIA_SLOPE_BOTH, "%u", "memcache", NULL, "Memcache Current Items" )
SFLOW_GMETRIC(SFLOW_M_mc_total_items, "mc_total_items", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Total Items" )
SFLOW_GMETRIC(SFLOW_M_mc_evictions, "mc_evictions", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Evictions" )
SFLOW_GMETRIC(SFLOW_M_mc_cmd_touch, "mc_cmd_touch", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache CMD Touch" )
SFLOW_GMETRIC(SFLOW_M_mc_rejected_conns, "mc_rejected_conns", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Rejected Connections" )
SFLOW_GMETRIC(SFLOW_M_mc_reclaimed, "mc_reclaimed", "", GANGLIA_SLOPE_BOTH, "%.2f", "memcache", NULL, "Memcache Reclaimed" )
SFLOW_GMETRIC(SFLOW_M_http_meth_option, "http_meth_option", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method OPTION" )
SFLOW_GMETRIC(SFLOW_M_http_meth_get, "http_meth_get", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method GET" )
SFLOW_GMETRIC(SFLOW_M_http_meth_head, "http_meth_head", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method HEAD" )
SFLOW_GMETRIC(SFLOW_M_http_meth_post, "http_meth_post", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method POST" )
SFLOW_GMETRIC(SFLOW_M_http_meth_put, "http_meth_put", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method PUT" )
SFLOW_GMETRIC(SFLOW_M_http_meth_delete, "http_meth_delete", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method DELETE" )
SFLOW_GMETRIC(SFLOW_M_http_meth_trace, "http_meth_trace", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method TRACE" )
SFLOW_GMETRIC(SFLOW_M_http_meth_connect, "http_meth_connect", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method CONNECT" )
SFLOW_GMETRIC(SFLOW_M_http_meth_other, "http_meth_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Method other" )
SFLOW_GMETRIC(SFLOW_M_http_status_1XX, "http_status_1XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 1XX" )
SFLOW_GMETRIC(SFLOW_M_http_status_2XX, "http_status_2XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 2XX" )
SFLOW_GMETRIC(SFLOW_M_http_status_3XX, "http_status_3XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 3XX" )
SFLOW_GMETRIC(SFLOW_M_http_status_4XX, "http_status_4XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 4XX" )
SFLOW_GMETRIC(SFLOW_M_http_status_5XX, "http_status_5XX", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status 5XX" )
SFLOW_GMETRIC(SFLOW_M_http_status_other, "http_status_other", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Status other" )
SFLOW_GMETRIC(SFLOW_M_http_workers_active, "http_workers_active", "", GANGLIA_SLOPE_BOTH, "%u", "httpd", NULL, "HTTP Workers Active" )
SFLOW_GMETRIC(SFLOW_M_http_workers_idle, "http_workers_idle", "", GANGLIA_SLOPE_BOTH, "%u", "httpd", NULL, "HTTP Workers Idle" )
SFLOW_GMETRIC(SFLOW_M_http_workers_max, "http_workers_max", "", GANGLIA_SLOPE_ZERO, "%u", "httpd", NULL, "HTTP Workers Max" )
SFLOW_GMETRIC(SFLOW_M_http_workers_req_delayed, "http_workers_req_delayed", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Requests Delayed" )
SFLOW_GMETRIC(SFLOW_M_http_workers_req_dropped, "http_workers_req_dropped", "", GANGLIA_SLOPE_BOTH, "%.2f", "httpd", NULL, "HTTP Requests Dropped" )
SFLOW_GMETRIC(SFLOW_M_jvm_hmem_initial, "jvm_hmem_initial", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Initial" )
SFLOW_GMETRIC(SFLOW_M_jvm_hmem_used, "jvm_hmem_used", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Used" )
SFLOW_GMETRIC(SFLOW_M_jvm_hmem_committed, "jvm_hmem_committed", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Committed" )
SFLOW_GMETRIC(SFLOW_M_jvm_hmem_max, "jvm_hmem_max", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Heap Max" )
SFLOW_GMETRIC(SFLOW_M_jvm_nhmem_initial, "jvm_nhmem_initial", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Non-Heap Initial" )
SFLOW_GMETRIC(SFLOW_M_jvm_nhmem_used, "jvm_nhmem_used", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Non-Heap Used" )
SFLOW_GMETRIC(SFLOW_M_jvm_nhmem_committed, "jvm_nhmem_committed", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Non-Heap Committed" )
SFLOW_GMETRIC(SFLOW_M_jvm_nhmem_max, "jvm_nhmem_max", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Non-Heap Max" )
SFLOW_GMETRIC(SFLOW_M_jvm_gc_count, "jvm_gc_count", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM GC count" )
SFLOW_GMETRIC(SFLOW_M_jvm_gc_cpu, "jvm_gc_cpu", "%", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM GC CPU" )
SFLOW_GMETRIC(SFLOW_M_jvm_cls_loaded, "jvm_cls_loaded", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Classes Loaded" )
SFLOW_GMETRIC(SFLOW_M_jvm_cls_total, "jvm_cls_total", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Classes Total" )
SFLOW_GMETRIC(SFLOW_M_jvm_cls_unloaded, "jvm_cls_unloaded", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Classes Unloaded" )
SFLOW_GMETRIC(SFLOW_M_jvm_comp_cpu, "jvm_comp_cpu", "%", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Compilation CPU" )
SFLOW_GMETRIC(SFLOW_M_jvm_thread_live, "jvm_thread_live", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Threads Live" )
SFLOW_GMETRIC(SFLOW_M_jvm_thread_daemon, "jvm_thread_daemon", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Threads Daemon" )
SFLOW_GMETRIC(SFLOW_M_jvm_thread_started, "jvm_thread_started", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM Threads Started" )
SFLOW_GMETRIC(SFLOW_M_jvm_fds_open, "jvm_fds_open", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM FDs Open" )
SFLOW_GMETRIC(SFLOW_M_jvm_fds_max, "jvm_fds_max", "", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM FDs Max" )
SFLOW_GMETRIC(SFLOW_M_jvm_vcpu_util, "jvm_vcpu_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "jvm", NULL, "JVM CPU Utilization" )
SFLOW_GMETRIC(SFLOW_M_jvm_vmem_total, "jvm_vmem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "jvm", NULL, "JVM Memory Total" )
SFLOW_GMETRIC(SFLOW_M_jvm_vmem_util, "jvm_vmem_util", "%", GANGLIA_SLOPE_ZERO, "%.2f", "jvm", NULL, "JVM Memory Utilization" )
SFLOW_GMETRIC(SFLOW_M_jvm_release, "jvm_release", "", GANGLIA_SLOPE_ZERO, "%s", "jvm", NULL, "JVM Release" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_count, "nvml_gpu_count", "", GANGLIA_SLOPE_ZERO, "%u", "nvml", NULL, "NVML GPU Count" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_processes, "nvml_gpu_processes", "", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Processes" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_time, "nvml_gpu_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Utilization" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_rw_time, "nvml_gpu_rw_util", "%", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Mem R/W Utilization" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_mem_total, "nvml_gpu_mem_total", "KB", GANGLIA_SLOPE_ZERO, "%.0f", "nvml", NULL, "NVML GPU Mem Total" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_mem_free, "nvml_gpu_mem_free", "KB", GANGLIA_SLOPE_BOTH, "%.0f", "nvml", NULL, "NVML GPU Mem Free" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_ecc_errors, "nvml_gpu_ecc_errors", "", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU ECC Errors" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_energy, "nvml_gpu_power", "W", GANGLIA_SLOPE_BOTH, "%.2f", "nvml", NULL, "NVML GPU Power" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_temperature, "nvml_gpu_temperature", "C", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Temperature" )
SFLOW_GMETRIC(SFLOW_M_nvml_gpu_fan_speed, "nvml_gpu_fan_speed", "%", GANGLIA_SLOPE_BOTH, "%u", "nvml", NULL, "NVML GPU Fan Speed" )
